From: Junio C Hamano Date: Thu, 26 Feb 2009 09:05:18 GMT Subject: Re: [PATCH 4/4] diffcore-pickaxe: optimize by trimming common initial and trailing parts Message-ID: <7vy6vtva9d.fsf@gitster.siamese.dyndns.org> In-Reply-To: <30c0d4d9b64924679c9af00796f7e0b562020ddf.1235629933.git.gitster@pobox.com> Junio C Hamano writes: > With this optimization in place, the following query in the Linux kernel > repository on my machine becomes about 40% faster: > > $ STRING='Ensure that the real time constraints are schedulable.' > $ git log -S"$STRING" HEAD -- kernel/sched.c >/dev/null > > (Before the patch, best of 5 runs) > 5.59user 0.15system 0:05.74elapsed 99%CPU (0avgtext+0avgdata 0maxresident)k > 0inputs+0outputs (0major+39956minor)pagefaults 0swaps > > (After the patch, best of 5 runs) > 3.04user 0.17system 0:03.23elapsed 99%CPU (0avgtext+0avgdata 0maxresident)k > 0inputs+0outputs (0major+49697minor)pagefaults 0swaps The file "kernel/sched.c" has roughly 900 changes applied to it, and over its lifetime, it has grown from 5kB to 9kB in size. I suspect a larger file might see a bigger performance boost.